//
//  TSEmojisChildVC.swift
//  AIEmoji
//
//  Created by 100Years on 2025/1/16.
//

import JXSegmentedView
import JXPagingView
import MJRefresh

class TSEmojisChildVC: UIViewController {
    
    
    var listViewDidScrollCallback: ((UIScrollView) -> ())?
    let collectionView: UICollectionView
    override init(nibName nibNameOrNil: String?, bundle nibBundleOrNil: Bundle?) {
        let itemMargin: CGFloat = 10
        let itemWidth = floor((UIScreen.main.bounds.size.width - itemMargin*4)/3)
        let layout = UICollectionViewFlowLayout()
        layout.itemSize = CGSize(width: itemWidth, height: itemWidth)
        layout.sectionInset = UIEdgeInsets.init(top: itemMargin, left: itemMargin, bottom: itemMargin, right: itemMargin)
        layout.scrollDirection = .vertical
        collectionView = UICollectionView(frame: CGRect.zero, collectionViewLayout: layout)
        super.init(nibName: nibNameOrNil, bundle: nibBundleOrNil)

    }

    required init?(coder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }

    override func viewDidLoad() {
        super.viewDidLoad()

        collectionView.alwaysBounceHorizontal = false
        collectionView.backgroundColor = .white
        collectionView.dataSource = self
        collectionView.delegate = self
        collectionView.register(ListCollectionViewCell.self, forCellWithReuseIdentifier: "cell")
        //列表的contentInsetAdjustmentBehavior失效，需要自己设置底部inset
        collectionView.contentInset = UIEdgeInsets(top: 0, left: 0, bottom: 0, right: 0)
        view.addSubview(collectionView)
        
        collectionView.mj_header = MJRefreshNormalHeader(refreshingTarget: self, refreshingAction: #selector(headerRefresh))
        collectionView.mj_footer = MJRefreshAutoNormalFooter(refreshingTarget: self, refreshingAction: #selector(loadMore))
        collectionView.contentInsetAdjustmentBehavior = .never
        
   
    }
    
    override func viewDidLayoutSubviews() {
        super.viewDidLayoutSubviews()

        collectionView.frame = view.bounds
    }
    
    @objc func headerRefresh() {
        DispatchQueue.main.asyncAfter(deadline: DispatchTime.now() + DispatchTimeInterval.seconds(2)) {
            self.collectionView.mj_header?.endRefreshing()
     
            self.collectionView.reloadData()
        }
    }

    @objc func loadMore() {
        DispatchQueue.main.asyncAfter(deadline: DispatchTime.now() + DispatchTimeInterval.seconds(2)) {
  
            self.collectionView.reloadData()
            self.collectionView.mj_footer?.endRefreshing()
        }
    }
}

extension TSEmojisChildVC: UICollectionViewDataSource, UICollectionViewDelegate {
    public func collectionView(_ collectionView: UICollectionView, numberOfItemsInSection section: Int) -> Int {
        return 20
    }

    public func collectionView(_ collectionView: UICollectionView, cellForItemAt indexPath: IndexPath) -> UICollectionViewCell {
        let cell = collectionView.dequeueReusableCell(withReuseIdentifier: "cell", for: indexPath) as! ListCollectionViewCell
        cell.contentView.backgroundColor = .lightGray
        cell.titleLabel.text = String(format: "%d", indexPath.item)
        return cell
    }
}

class ListCollectionViewCell: UICollectionViewCell {
    lazy var titleLabel: UILabel = UILabel()

    override init(frame: CGRect) {
        super.init(frame: frame)

        titleLabel.textAlignment = .center
        addSubview(titleLabel)
    }

    required init?(coder aDecoder: NSCoder) {
        fatalError("init(coder:) has not been implemented")
    }

    override func layoutSubviews() {
        super.layoutSubviews()

        titleLabel.frame = self.contentView.bounds
    }
}

extension TSEmojisChildVC: JXPagingViewListViewDelegate {
    
    func listScrollView() -> UIScrollView { collectionView }
    
    func scrollViewDidScroll(_ scrollView: UIScrollView) {
        listViewDidScrollCallback?(scrollView)
    }
    
    
    func listViewDidScrollCallback(callback: @escaping (UIScrollView) -> ()) {
        listViewDidScrollCallback = callback
    }

    func listView() -> UIView { view }
    
    func listWillAppear() {
        print("\(title ?? ""):\(#function)")
    }

    func listDidAppear() {
        print("\(title ?? ""):\(#function)")
    }

    func listWillDisappear() {
        print("\(title ?? ""):\(#function)")
    }

    func listDidDisappear() {
        print("\(title ?? ""):\(#function)")
    }
}
