//
//  TSEmojisVC.swift
//  AIEmoji
//
//  Created by 100Years on 2025/1/15.
//

import JXSegmentedView
import JXPagingView
class TSEmojisVC: TSBaseVC {
    
    let viewModel = TSEmojisColViewModel()
    
    lazy var pagingView: JXPagingView = {
        //lazy var pagingView: JXPagingView = JXPagingListRefreshView(delegate: self) //整个刷新
//        let pagingView = JXPagingListRefreshView(delegate: self) //list 刷新
        let pagingView = JXPagingView(delegate: self) //list 刷新
        pagingView.mainTableView.backgroundColor = .clear
        return pagingView
    }()

    lazy var segmentedDataSource: JXSegmentedTitleDataSource = {
        let titles = ["Solid Color".localized, "Gradient Color".localized, "Shape".localized]
        let dataSource = JXSegmentedTitleDataSource()
        dataSource.isTitleColorGradientEnabled = true
        dataSource.titles = viewModel.emojisTypes
        dataSource.titleNormalColor = .white
        dataSource.titleSelectedColor = .mainBg
        dataSource.titleNormalFont = .font(size: 16.0)
        return dataSource
    }()
    
    //配置指示器
    lazy var indicator: JXSegmentedIndicatorBackgroundView = {
        let indicator = JXSegmentedIndicatorBackgroundView()
        indicator.isIndicatorConvertToItemFrameEnabled = true
        indicator.indicatorHeight = 30
        indicator.indicatorColor = .white
        return indicator
    }()
    
    //头 view
    lazy var segmentedView: JXSegmentedView = {
        let segmentedView = JXSegmentedView(frame: CGRect(x: 0, y: 0, width: UIScreen.main.bounds.size.width, height: CGFloat(headerInSectionHeight)))
        segmentedView.delegate = self
        segmentedView.indicators = [indicator]
        segmentedView.dataSource = segmentedDataSource
        segmentedView.backgroundColor = .clear
        
        segmentedView.listContainer = pagingView.listContainerView as? any JXSegmentedViewListContainer
        return segmentedView
    }()

    var tableHeaderViewHeight: Int = 200
    var headerInSectionHeight: Int = 50
    
    lazy var headerView: UIView = {
        let view = UIView(frame: CGRect(x: 0, y: 0, width: UIScreen.main.bounds.size.width, height: CGFloat(tableHeaderViewHeight)))
        view.backgroundColor = .gray
        return view
    }()
    
    lazy var navBarView: TSBaseNavContentBarView = {
        let navBarView = TSBaseNavContentBarView()
        
        let titleImageView = UIImageView.createImageView(imageName: "nav_title_emojis",contentMode: .scaleToFill)
        navBarView.barView.addSubview(titleImageView)
        titleImageView.snp.makeConstraints { make in
            make.centerY.equalToSuperview()
            make.left.equalTo(16)
        }
        
        let setBtn = UIButton.createButton(image: UIImage(named: "setting")) { [weak self]  in
            guard let self = self else { return }
            let setingVC = TSSetingVC()
            setingVC.hidesBottomBarWhenPushed = true
            navigationController?.pushViewController(setingVC, animated: true)
        }
        navBarView.barView.addSubview(setBtn)
        setBtn.snp.makeConstraints { make in
            make.centerY.equalToSuperview()
            make.trailing.equalTo(-16)
            make.width.height.equalTo(24)
        }
        
        return navBarView
    }()
    
    override func createView() {

        navBarContentView.addSubview(navBarView)
        navBarView.snp.makeConstraints { make in
            make.edges.equalToSuperview()
        }
        
        contentView.addSubview(segmentedView)
      
        pagingView.frame = self.view.bounds
        contentView.addSubview(pagingView)

        //扣边返回处理，下面的代码要加上
        pagingView.listContainerView.scrollView.panGestureRecognizer.require(toFail: self.navigationController!.interactivePopGestureRecognizer!)
        pagingView.mainTableView.panGestureRecognizer.require(toFail: self.navigationController!.interactivePopGestureRecognizer!)
        
        
        
//        kDelayOnMainThread(2) {
//            self.tableHeaderViewHeight = 0
//            self.pagingView.reloadData()
//        }
    }
}



extension TSEmojisVC: JXPagingViewDelegate {

    func tableHeaderViewHeight(in pagingView: JXPagingView) -> Int {
        return tableHeaderViewHeight
    }

    func tableHeaderView(in pagingView: JXPagingView) -> UIView {
        return headerView
    }

    func heightForPinSectionHeader(in pagingView: JXPagingView) -> Int {
        return headerInSectionHeight
    }

    func viewForPinSectionHeader(in pagingView: JXPagingView) -> UIView {
        return segmentedView
    }

    func numberOfLists(in pagingView: JXPagingView) -> Int {
        return viewModel.emojisTypes.count
    }

    func pagingView(_ pagingView: JXPagingView, initListAtIndex index: Int) -> JXPagingViewListViewDelegate {
        return TSEmojisChildVC()
    }
}

extension TSEmojisVC: JXSegmentedViewDelegate {
    func segmentedView(_ segmentedView: JXSegmentedView, didSelectedItemAt index: Int) {
        self.navigationController?.interactivePopGestureRecognizer?.isEnabled = (index == 0)
    }
}
